#import
how to import: import jscript

#packages required

pip install os

#sample code

```python
import jscript as js
js.console.log("hi")
js.console.warn("daw")
js.console.error("daw")
js.console.count(6)
prompt("dawdawd") #this one has bugs
#thats all for now
```